# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python
from pupy.savings_n_loads import ljson
from pupy.savings_n_loads import load_jasm
from pupy.savings_n_loads import lstring
from pupy.savings_n_loads import lstr
from pupy.savings_n_loads import lpak
from pupy.savings_n_loads import safepath
from pupy.savings_n_loads import save_jasm
from pupy.savings_n_loads import sstr
from pupy.savings_n_loads import sstring
from pupy.savings_n_loads import savings
from pupy.savings_n_loads import sjson
from pupy.savings_n_loads import spak



# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python

from typing import Union

def safepath(filepath: str): ...
def sstring(filepath: str, string: str) -> None: ...
def sstr(filepath: str, string: str) -> None: ...
def savings(filepath: str, string: str) -> None: ...
def lstring(filepath: str): ...
def lstr(filepath: str): ...
def sjson(filepath: str, data: Union[list, dict], min: bool = ...) -> None: ...
def save_jasm(filepath: str, data: Union[list, dict], min: bool = ...): ...
def sjasm(filepath: str, data: Union[list, dict], min: bool = ...): ...
def spak(filepath: str, data: Union[list, dict], min: bool = ...): ...
def ljson(filepath: str): ...
def load_jasm(filepath: str): ...
def ljasm(filepath: str): ...
def lpak(filepath: str): ...
def touch(filepath: str) -> None: ...
